<template>
    <div class="drag-box" ref="drag-box">
        <div class="drag-left">
            <div class="common-tree-container">
                <div class="common-tree-title">
                    <i class="el-icon-menu"></i> 监控设备
                </div>
                <div class="tree-search-wrapper flex">
                    <el-select
                        class="tree-select"
                        v-model="treeTollStationId"
                        filterable
                        placeholder="收费站"
                        @change="changeTollStation"
                    >
                        <el-option
                            v-for="item in tollStationOptions"
                            :key="item.id + 'tree'"
                            :label="item.name"
                            :value="item.id"
                        >
                        </el-option>
                    </el-select>
                    <el-input
                        clearable
                        class="tree-input"
                        v-model="sreachTree"
                        placeholder="输入关键字"
                    >
                        <i
                            slot="prefix"
                            class="el-input__icon el-icon-search"
                        ></i>
                    </el-input>
                </div>
                <div class="common-tree-content" v-loading="treeLoading">
                    <el-tree
                        ref="tree"
                        highlight-current
                        v-if="treeData.length"
                        :data="treeData"
                        :props="defaultProps"
                        @node-click="handleNodeClick"
                        default-expand-all
                        node-key="id"
                        :filter-node-method="filterNode"
                    >
                        <span
                            class="custom-tree-node"
                            slot-scope="{node, data}"
                        >
                            <span>
                                <i
                                    v-if="data.cameraType == 1"
                                    class="btn-icon iconfont icon-sfz-qiangji"
                                ></i>
                                <i
                                    v-if="data.cameraType == 2"
                                    class="btn-icon iconfont icon-sfz-qiuji"
                                ></i>
                                <i
                                    v-if="data.cameraType == 3"
                                    class="btn-icon iconfont icon-sfz-banqiu"
                                ></i>
                                <!-- 摄像头类型 cameraType -->
                                <span> {{ node.label }}</span></span
                            >
                        </span>
                    </el-tree>
                    <el-empty v-else></el-empty>
                </div>
            </div>
        </div>
        <div class="drag-resize" title="收缩侧边栏">⋮</div>
        <div class="drag-right">
            <!-- <player ref="dh-player" class="player-outer"></player> -->
            <player ref="hk-player" class="player-outer"></player>
        </div>
    </div>
</template>

<script>
import {dragController} from '@/assets/js/dragController'
import {TableMixin} from '@/mixins/tableMixin'
import routerManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import device from '@/api/DeviceManagement/device.js'
import utils from '@/utils.js'
import player from '@/views/Normal/components/videoPlayerHK.vue'
export default {
    name: 'videoData',
    components: {player},
    mixins: [TableMixin],
    data() {
        return {
            treeLoading: false,
            treeTollStationId: '',
            treeTollStationName: '',
            tollStation: null, // 当前收费站信息
            sreachTree: '',
            currentTreeId: '',
            treeData: [
                // {
                //     label: '一级 1',
                //     id: 1,
                //     children: [],
                // },
            ],
            defaultProps: {
                children: 'children',
                label: 'name',
            },
            tollStationOptions: [], // 收费站数据
            loading: false,
        }
    },
    watch: {
        sreachTree(val) {
            this.$refs.tree.filter(val)
        },
    },
    computed: {
        SearchPanel() {
            return {
                '--searchPanel': this.searchPanel + 'px',
            }
        },
    },
    mounted() {
        dragController()
        this.loadTollStation()
    },
    methods: {
        // 收费站
        loadTollStation() {
            let params = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
            }
            routerManagement.queryTollStation(params).then((res) => {
                let data = res.data
                this.tollStationOptions = data.rows || []
                this.treeTollStationId = this.tollStationOptions[0].id
                this.treeTollStationName = this.tollStationOptions[0].name
                if (this.treeTollStationId) {
                    this.loadTree()
                    this.tollStation = this.tollStationOptions[0]
                }
            })
        },
        changeTollStation(val) {
            let options = utils.deepClone(this.tollStationOptions)
            let target = options.filter((item) => (item.id = val))[0]

            this.treeTollStationId = val
            this.treeTollStationName = target.name
            if (this.treeTollStationId) {
                this.loadTree()
                this.tollStation = target
            }
        },
        loadTree() {
            this.treeLoading = true
            this.treeData = []
            let queryData = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'tollStationId',
                        relation: 'AND',
                        value: this.treeTollStationId,
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'type',
                        relation: 'AND',
                        value: 1,
                    },
                ],
                sorter: [
                    {
                        direction: 'ASC',
                        property: 'sn_',
                    },
                    {
                        direction: 'ASC',
                        property: 'name',
                    },
                ],
            }
            device.queryDeviceList(queryData).then((res) => {
                this.treeLoading = false
                this.treeData = res.value.rows || []
            })
        },
        filterNode(value, data) {
            if (!value) return true
            return data.name.indexOf(value) !== -1
        },
        handleNodeClick(obj, node, tree) {
            this.currentTreeId = obj.id
            // this.$refs['dh-player'].play(obj)
            if (obj.cameraCode) {
                this.$refs['hk-player'].getVideoURL(obj.cameraCode)
            }
        },
        play() {
            this.$refs['hk-player'].getVideoURL('12')
        },
    },
}
</script>

<style lang='scss' scoped>
.drag-left {
    width: calc(20% - 10px); /*左侧初始化宽度*/
}
/*右侧div'样式*/
.drag-right {
    width: 80%; /*右侧初始化宽度*/
}
.custom-tree-node{
    span, i{
        font-size: 16px;
    }
    .el-icon-s-management,.btn-icon{
        color: #ffc71c;
    }
}
.common-tree-content{
    height: calc(100% - 60px - 56px) !important;
}
.add-tree-type{
    width: calc(100% - 20px);
    height: 40px;
    margin-top: 10px;
    margin-left: 10px;
}
.popover-btn-wrapper{
    // width: 80px;
    .popover-btn{
        font-size: 14px;
        padding: 8px 10px;
        cursor: pointer;
        i{
            font-size: 14px;
            margin-right: 6px;
        }
    }
    .popover-btn:hover{
        background-color: #edf6ff;
        color: #409eff;
    }
}

.tree-search-wrapper{
    gap: 10px;
    padding: 0 10px;
    box-sizing: border-box;
    width: 100%;
}
.common-tree-container {
    .tree-select,.tree-input{
        flex: 1;
        margin: 0;
        /deep/ .el-input{
            width: 100% !important;
            margin: 0;
        }
    }
    .el-input{
        width: 100% !important;
        margin: 0;
    }
}
.player-outer{
    margin: 10px;
    width: calc(100% - 20px);
    height: calc(100% - 20px);
}
</style>
<style lang='scss'>
.el-popover.tree-popover{
    min-width: 120px;
    padding-left: 0;
    padding-right: 0;
}
</style>